.. File auto-generated by ``generate_summary_table.py``

.. tabularcolumns:: |p{2cm}|p{3cm}|p{15cm}|

.. list-table:: Geo2Grid Reader Summary Table
    :header-rows: 1

    * - **Reader Name**
      - **Input Source**
      - **Input Filename Pattern**
    * - abi_l1b
      - ABI L1B
      - ``OR_ABI-L1b-Rad?-M?C??_G??_s<YYYYDDDHHMMSSS_eYYYYDDDHHMMSSS_c*.nc``

        **Ex: OR_ABI-L1b-RadF-M3C03_G16_s20183161830345_e20183161841112_c20183161841154.nc**
    * - ahi_hsd
      - AHI HSD
      - ``HS_H08_YYYYMMDD_HHMM_B??_*_*_S*.DAT``

        **Ex: HS_H08_20181112_1230_B08_FLDK_R20_S0910.DAT**
    * - ahi_hrit
      - AHI HRIT (HimawariCast) from JMA
      - ``IMG_DK01B??_YYYYMMDDHHMM``

        **Ex: IMG_DK01B05_201811121230**
    * - fci_l1c_nc
      -  MTG FCI Level 1C from EUMETSAT
      - ``W_XX-EUMETSAT-Darmstadt,IMG+SAT,MTI1+FCI-1C-RRAD-FDHSI-FD*_N_JLS_C_*.nc``

        **Ex: W_XX-EUMETSAT-Darmstadt,IMG+SAT,MTI1+FCI-1C-RRAD-FDHSI-FD--CHK-BODY--DIS-NC4E_C_EUMT_20231201115940_IDPFI_OPE_20231201115729_20231201115803_N_JLS_C_0072_0032.nc**
    * - ami_l1b
      - GEO-KOMPSAT AMI from KMA
      - ``gk2a_ami_le1b_?????_fd0??ge_YYYYMMDDHHMM.nc``

        **Ex: gk2a_ami_le1b_vi006_fd005ge_201909300300.nc**
    * - agri_fy4a_l1
        agri_fy4b_l1
      - FY4A, FY4B AGRI from CMA
      - ``FY4A-_AGRI--_N_DISK_1047E_L1-_???-MULT_NOM_YYYYMMDDHHMMSS_*_????M_V0001.HDF``

        ``FY4B-_AGRI--_N_DISK_1330E_L1-_???-MULT_NOM_YYYYMMDDHHMMSS_*_????M_V0001.HDF``

        **Ex: FY4A-_AGRI--_N_DISK_1047E_L1-_FDI-_MULT_NOM_20220120040000_*_1000M_V0001.HDF**

        **Ex: FY4B-_AGRI--_N_DISK_1330E_L1-_FDI-_MULT_NOM_20221115030000_*_0500M_V0001.HDF**
    * - abi_l2_nc
      - ABI Product Cloud Height and Cloud Top Temperature
      - ``CG_ABI-L2-{PROD}F-M6_G??_sYYYYDDDHHMMSSS_*.nc``

        **Ex: CG_ABI-L2-ACHAF-M6_G17_s20223271830316_e20223271839394_c20223271842100.nc**

        **Ex: CG_ABI-L2-ACHTF-M6_G17_s20223271830316_e20223271839394_c20223271842100.nc**
    * - glm_l2
      - CSPP Gridded GLM Product
      - ``CG_GLM-L2-GLM?-M3_G??_sYYYYDDDHHMMSSS_*.nc``

        **Ex: CG_GLM-L2-GLMF-M3_G18_s20223141900000_e20223141901000_c20223142002160.nc**
